@@ -10,6 +10,10 @@ import sys
 import tempfile
 import numpy as np
 
+from wand.api import library
+from wand.color import Color
+from wand.image import Image
+
 import pcbnew
 from lxml import etree
 
@@ -504,14 +508,15 @@ def print_component(paths, lib, name, value, ref, pos, remapping={}):
         ref, lib, name, pos[0], pos[1], math.degrees(pos[2]), f if f else "Not found")
     print(msg)
 
-def component_from_library(lib, name, value, ref, pos, comp, highlight):
+def component_from_library(lib, name, value, ref, pos, comp, highlight, silent):
     if not name:
         return
     if comp["filter"] is not None and ref not in comp["filter"]:
         return
     f = get_model_file(comp["libraries"], lib, name, ref, comp["remapping"])
     if not f:
-        print("Warning: component '{}' for footprint '{}' from library '{}' was not found".format(name, ref, lib))
+        if not silent:
+            print("Warning: component '{}' for footprint '{}' from library '{}' was not found".format(name, ref, lib))
         if comp["placeholder"]:
             etree.SubElement(comp["container"], "rect", x=str(ki2dmil(pos[0]) - 150), y=str(ki2dmil(pos[1]) - 150),
                              width="300", height="300", style="fill:red;")
@@ -559,20 +564,14 @@ def build_highlight(preset, width, height, pos, origin, ref):
     h.attrib["id"] = "h_" + ref
 
 def svg_to_png(infile, outfile, dpi=300):
-    import cairo
-    import gi
-    gi.require_version('Rsvg', '2.0')
-    from gi.repository import Rsvg
-
-    handle = Rsvg.Handle()
-    svg = handle.new_from_file(infile)
-    svg.set_dpi(dpi)
-    dim = svg.get_dimensions()
-    w, h = dim.width, dim.height
-    img =  cairo.ImageSurface(cairo.FORMAT_ARGB32, w, h)
-    ctx = cairo.Context(img)
-    svg.render_cairo(ctx)
-    img.write_to_png(outfile)
+    with Image(resolution=300) as image:
+        with Color('transparent') as background_color:
+            library.MagickSetBackgroundColor(image.wand,
+                                            background_color.resource)
+        image.read(filename=infile, resolution=300)
+        png_image = image.make_blob("png32")
+        with open(outfile, "wb") as out:
+            out.write(png_image)
 
 def load_style(style_file):
     try:
@@ -627,6 +626,7 @@ def main():
     parser.add_argument("-a", "--highlight", help="comma separated list of components to highlight")
     parser.add_argument("-f", "--filter", help="comma separated list of components to show")
     parser.add_argument("-v", "--vcuts", action="store_true", help="Render V-CUTS on the Cmts.User layer")
+    parser.add_argument("--silent", action="store_true", help="Silent warning messages about missing footprints")
 
     args = parser.parse_args()
     args.libs = [adjust_lib_path(path) for path in args.libs.split(',')]
@@ -702,17 +702,17 @@ def main():
         board_cont.append(get_layers(board, style, [("vcut", [pcbnew.Cmts_User], process_board_substrate_layer)]))
 
     walk_components(board, args.back, lambda lib, name, val, ref, pos:
-        component_from_library(lib, name, val, ref, pos, components, highlight))
+        component_from_library(lib, name, val, ref, pos, components, highlight, args.silent))
 
     #make another pass for search, and if found, render the back side of the component
     #the function will search for file with extension ".back.svg"
     walk_components(board, not args.back, lambda lib, name, val, ref, pos:
-        component_from_library(lib, name+".back", val, ref, pos, components, highlight))
+        component_from_library(lib, name+".back", val, ref, pos, components, highlight, args.silent))
 
     if args.output.endswith(".svg") or args.output.endswith(".SVG"):
         document.write(args.output)
     else:
-        with tempfile.NamedTemporaryFile() as tmp_f:
+        with tempfile.NamedTemporaryFile(suffix=".svg") as tmp_f:
             document.write(tmp_f)
             tmp_f.flush()
             svg_to_png(tmp_f.name, args.output)
